@@ -1,4 +1,4 @@
-#   Copyright 2011 Josh Kearney
+#   Copyright 2011-2016 Josh Kearney
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -17,14 +17,24 @@
 import os
 import unittest
 
-from pyhole.core import log, utils
+from pyhole.core import logger
+from pyhole.core import utils
 
 
-class TestLog(unittest.TestCase):
+class TestLogger(unittest.TestCase):
     def test_logger(self):
         test_log_dir = utils.get_home_directory() + "logs/"
-        log.setup_logger(name="test")
-        test_log = log.get_logger("TEST")
+
+        try:
+            # NOTE(jk0): If the configuration file doesn't exist, the config
+            # class will generate it and raise a SystemExit.
+            logger.setup_logger("test")
+        except SystemExit:
+            logger.setup_logger("test")
+
+        test_log = logger.get_logger("TEST")
+
         self.assertEqual("TEST", test_log.name)
         self.assertEqual(test_log.level, 0)
+
         os.unlink(test_log_dir + "test.log")
